/****************************************************************************/

#include "traydebug.h"

/*****************************************************************************
 * Name         - CenterWindow
 * Purpose      - This centers the child window given over the other window
 *                given. Used to put the dialogs used by the program into
 *                a more desirable position.
 * Arguments    - hwndChild: The window to center
 *                hwndParent: The parent to center the child over
 * Return Value - TRUE on Successes, FALSE on Failure
 ****************************************************************************/
BOOL CenterWindow (HWND hwndChild , HWND hwndParent)
{
 WINASSERT (hwndChild);
 WINASSERT (hwndParent);

 RECT    rcChild , rcParent;
 int     cxChild , cyChild , cxParent , cyParent;
 int     cxScreen , cyScreen , xNew , yNew;
 HDC     hdc;

 // Get the Height and Width of the child window
 GetWindowRect (hwndChild , &rcChild);
 cxChild = rcChild.right - rcChild.left;
 cyChild = rcChild.bottom - rcChild.top;

 // Get the Height and Width of the parent window
 GetWindowRect (hwndParent , &rcParent);
 cxParent = rcParent.right - rcParent.left;
 cyParent = rcParent.bottom - rcParent.top;

 // Get the display limits
 hdc = GetDC (hwndChild);
 cxScreen = GetDeviceCaps (hdc , HORZRES);
 cyScreen = GetDeviceCaps (hdc , VERTRES);
 ReleaseDC (hwndChild , hdc);

 // Calculate new X position, then adjust for screen
 xNew = rcParent.left + ((cxParent - cxChild) / 2);
 if (xNew < 0) {
     xNew = 0;
 } else
     if ((xNew + cxChild) > cxScreen) {
         xNew = cxScreen - cxChild;
     }

 // Calculate new Y position, then adjust for screen
 yNew = rcParent.top  + ((cyParent - cyChild) / 2);
 if (yNew < 0) {
     yNew = 0;
 } else
     if ((yNew + cyChild) > cyScreen) {
         yNew = cyScreen - cyChild;
     }

 // Set it, and return
 return SetWindowPos (hwndChild , NULL , xNew , yNew , 0 , 0 ,
                      SWP_NOSIZE | SWP_NOZORDER);
}

/****************************************************************************/

