/****************************************************************************/

#include "traydebug.h"

/*****************************************************************************
 * Name         - WinLibMain
 * Purpose      - This is the entry point to the program. It sets up the
 *                application and then starts the message loop that runs
 *                the program.
 * Arguments    - hInstance: Instance handle of the program
 *                lpCmdLine: Pointer to the string command line of the prog
 *                nCmdShow: Initial show state for the window
 * Return Value - FALSE if there is a problem
 *                WPARAM value of the Quit message that terminated the app on
 *                success.
 ****************************************************************************/
int winLibMain (HINSTANCE hInstance,
                LPSTR     lpCmdLine,
                int       nCmdShow)
{
 MSG Msg;

 // Initialize application by setting up the main window.
 if (!InitApplication (hInstance, lpCmdLine , nCmdShow)) {
     ExitApplication ();
     return FALSE;
 }

 // Here we loop forever. The main loop will break as soon as a WM_QUIT message
 // received.
 while (1) {
     // Check to see if there is a message. If there is, then we want to
     // dispatch it. Otherwise, do the idle processing.
     if (PeekMessage (&Msg , NULL , 0 , 0 , PM_NOREMOVE)) {
         // If GetMessage returns 0, it means that a WM_QUIT message was
         // received. If that is the case, break out of this loop.
         if (!GetMessage (&Msg , NULL , 0 , 0))
             break;

         // It's not a WM_QUIT Message. Dispatch it in the usual manner
         TranslateMessage (&Msg);
         DispatchMessage (&Msg);
     } else {
         // Do some sort of idle processing here

         // Now sit and wait till a message shows up
         WaitMessage ();
     }
 }

 ExitApplication ();

 return Msg.wParam;
}

/****************************************************************************/

