/****************************************************************************/

#include "traydebug.h"

/****************************************************************************/

#define KEY_MAINREG         "software\\Black Spider\\TrayDebug"
#define KEY_DEBUGWINDOWPOS  "DebugWindowPosition"

/*****************************************************************************
 * Name         - SaveWINDOWPLACEMENTToRegistry
 * Purpose      - Saves a WINDOWPLACEMENT struct to the registry using the
 *                given key.
 * Arguments    - Var: Struct to save
 *                Key: Key to save the given var in
 * Return Value - None
 ****************************************************************************/
void SaveWINDOWPLACEMENTToRegistry (WINDOWPLACEMENT &Var , char *Key)
{
 WINASSERT (Key);
 HKEY RegKey;

 // Try to create the key that we will be saving our information into. If the
 // key doesn't exist it will then be created. If it does exist it will be
 // opened instead.
 if (RegCreateKeyEx (HKEY_CURRENT_USER , KEY_MAINREG , 0 , szAppName , 0 ,
                     KEY_ALL_ACCESS , NULL , &RegKey ,
                     NULL) == ERROR_SUCCESS) {

     // If we managed to open or create our key, we set the user mode key.
     // This will either create the key if it doesn't exist or update it if it
     // does. Once we are done we close the key.
     RegSetValueEx (RegKey , Key , 0 , REG_BINARY , (LPBYTE) &Var ,
                    sizeof (WINDOWPLACEMENT));
     RegCloseKey (RegKey);
 }
}

/*****************************************************************************
 * Name         - LoadWINDOWPLACEMENTFromRegistry
 * Purpose      - Loads a WINDOWPLACEMENT struct from the registry
 * Arguments    - Var: WINDOWPLACEMENT var to put the read value into.
 *                Key: Key to load the given var from
 * Return Value - TRUE if the WINDOWPLACEMENT  was read successfully
 *                FALSE if the WINDOWPLACEMENT could not be read. The var
 *                parameter is unchanged.
 ****************************************************************************/
BOOL LoadWINDOWPLACEMENTFromRegistry (WINDOWPLACEMENT &Var , char *Key)
{
 WINASSERT (Key);
 HKEY  RegKey   = 0;
 BOOL  Worked   = FALSE;
 WINDOWPLACEMENT ReadVal;
 DWORD DataSize = sizeof (WINDOWPLACEMENT);

 // Try to open up the registry key.
 if (RegOpenKeyEx (HKEY_CURRENT_USER , KEY_MAINREG , 0 , KEY_READ ,
                   &RegKey) == ERROR_SUCCESS) {
     // Once again, query the registry, and make sure that the function
     // returned ok and we got the right amount of data.
     if (RegQueryValueEx (RegKey , Key , 0 , NULL ,
                          (LPBYTE) &ReadVal , &DataSize) == ERROR_SUCCESS)
         Worked = (DataSize == sizeof (WINDOWPLACEMENT));

     // If it worked, set the return value to go back to the caller.
     if (Worked)
         Var = ReadVal;

     // Close the registry key
     RegCloseKey (RegKey);
 }

 // Return a value indicating if it worked or not.
 return Worked;
}

/*****************************************************************************
 * Name         - SaveDebugWindowPosition
 * Purpose      - This saves the position of the debug window into the registry
 * Arguments    - None
 * Return Value - None
 ****************************************************************************/
void SaveDebugWindowPosition (void)
{
 WINASSERT (hwndDebugClient);
 WINDOWPLACEMENT wp;

 wp.length = sizeof (WINDOWPLACEMENT);
 GetWindowPlacement (hwndDebugClient , &wp);
 SaveWINDOWPLACEMENTToRegistry (wp , KEY_DEBUGWINDOWPOS);
}

/*****************************************************************************
 * Name         - LoadDebugWindowPosition
 * Purpose      - This gets the debug window position out of the registry and
 *                puts it into the passed parameter. If the information
 *                cannot be loaded, the passed in variable is not altered.
 * Arguments    - wp: Handle to the WINDOWPLACEMENT structure to fill up with
 *                    the window position information
 * Return Value - TRUE on success or FALSE on failure
 ****************************************************************************/
BOOL LoadDebugWindowPostion (WINDOWPLACEMENT &wp)
{
 return LoadWINDOWPLACEMENTFromRegistry (wp , KEY_DEBUGWINDOWPOS);
}

/****************************************************************************/
